starcluster.plugins.ipcluster.IPCluster

Package starcluster :: Package plugins :: Module ipcluster :: Class IPCluster |
[hide private]
[frames] | no frames]

# Class IPCluster

source code

Starts an IPCluster on StarCluster

Instance Methods | [hide private]
_create_cluster_file(self, master, nodes) | source code
run(self, nodes, master, user, user_shell, volumes) Run this plugin's setup routines | source code
on_add_node(self, node, nodes, master, user, user_shell, volumes) This methods gets executed after a node has been added to the cluster | source code
on_remove_node(self, node, nodes, master, user, user_shell, volumes) This method gets executed before a node is about to be removed from the cluster | source code
Inherited from `clustersetup.ClusterSetup`: `__init__`, `on_restart`, `on_shutdown` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| cluster_file = ``'``/etc/clusterfile.py``'``
| log_file = ``'``/var/log/ipcluster.log``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### run(self, nodes, master, user, user_shell, volumes) | source code
Run this plugin's setup routines This method gets executed after the default cluster setup routines have been performed Overrides: clustersetup.ClusterSetup.run (inherited documentation)

### on_add_node(self, node, nodes, master, user, user_shell, volumes) | source code
This methods gets executed after a node has been added to the cluster Overrides: clustersetup.ClusterSetup.on_add_node (inherited documentation)

### on_remove_node(self, node, nodes, master, user, user_shell, volumes) | source code
This method gets executed before a node is about to be removed from the cluster Overrides: clustersetup.ClusterSetup.on_remove_node (inherited documentation)